/* Copyright (C) 2011, 2012, 2013 by Bundesanstalt für Gewässerkunde
 * Software engineering by Intevation GmbH
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.artifacts.sinfo.collision;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;
import org.dive4elements.artifacts.Artifact;
import org.dive4elements.artifacts.CallContext;
import org.dive4elements.artifacts.common.utils.XMLUtils.ElementCreator;
import org.dive4elements.river.artifacts.model.CollisionHibernateFactory;
import org.dive4elements.river.artifacts.sinfo.SINFOArtifact;
import org.dive4elements.river.artifacts.states.AddTableDataHelper;
import org.dive4elements.river.artifacts.states.DefaultState;
import org.dive4elements.river.model.sinfo.Collision;
import org.w3c.dom.Element;

public class LoadMultipleEpochSelectState extends DefaultState {
    /** The log used in this class. */
    private static Logger log = Logger.getLogger(LoadMultipleEpochSelectState.class);

    /**
     * The default constructor that initializes an empty State object.
     */
    public LoadMultipleEpochSelectState() {
    }

    @Override
    protected String getUIProvider() {
        return "sinfo.collision.load_epoch_select";
    }

    @Override
    protected void appendItems(final Artifact artifact, final ElementCreator creator, final String name, final CallContext context, final Element select) {
        final String datakey = "epochs";
        try {
            if (datakey.equals(name)) {

                final AddTableDataHelper helper = new AddTableDataHelper(creator, select, "year", context.getMeta());

                helper.addColumn(0, "pinfrom", "40", "common.client.ui.from", "ICON", "CENTER", "from");
                helper.addColumn(1, "pinto", "40", "common.client.ui.to", "ICON", "CENTER", "to");
                helper.addColumn(2, "year", "60", "year", "INTEGER", "LEFT", null);

                final CollisionAccess access = new CollisionAccess((SINFOArtifact) artifact); // Der River wurde im vorigen State bereits gesetzt

                final List<Collision> collisions = CollisionHibernateFactory.getCollisionsByRiver(access.getRiver());
                for (final Collision coll : collisions) { // TODO: Filter on Range (?)
                    final Integer year = coll.getYear();
                    final Map<String, String> row = new HashMap<>();
                    row.put("year", year.toString()); // Nullpointer?
                    helper.addRow(row);

                }
                helper.submitMapToXml();
            }
        }
        catch (final IllegalArgumentException iae) {
            iae.printStackTrace();
        }
    }
}
